#
# spec file for package scapy
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           scapy
Version:        2.6.1
Release:        1.2
Summary:        Interactive Packet Manipulation Tool
License:        GPL-2.0-only
Group:          Productivity/Networking/Security
URL:            https://scapy.net
Source:         https://github.com/secdev/scapy/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-base >= 3.7
BuildRequires:  python3-setuptools
Requires:       python3-cryptography
Recommends:     python3-PyX
Recommends:     python3-ipython
Provides:       python-scapy = %version
Obsoletes:      python-scapy < 2.2.0
BuildArch:      noarch

%description
Scapy is a powerful interactive packet manipulation tool, packet generator,
network scanner, network discovery tool, and packet sniffer. It provides
classes to interactively create packets or sets of packets, manipulate them,
send them over the wire, sniff other packets from the wire, match answers and
replies, and more. Interaction is provided by the Python interpreter, so Python
programming structures can be used (such as variables, loops, and functions).
Report modules are possible and easy to make. It is intended to do about the
same things as ttlscan, nmap, hping, queso, p0f, xprobe, arping, arp-sk,
arpspoof, firewalk, irpas, tethereal, tcpdump, etc.

%prep
%setup -q -n scapy-%{version}

# In (open)SUSE /etc/protocols and /etc/services
# moved to /usr/etc/
sed 's|%{_sysconfdir}/protocols|%{_prefix}%{_sysconfdir}/protocols|g' -i scapy/data.py
sed 's|%{_sysconfdir}/services|%{_prefix}%{_sysconfdir}/services|g' -i scapy/data.py

%build
%python3_build
#NOTE(saschpe): The documentation is CC-BY-SA-NC-2.5, thus we can not
# redistribute it (sr#172834):
rm -r doc/scapy

%install
%python3_install
# Fix non-executable-script rpmlint issue:
# WARN: Using simple globbing (*.py) will break manufdb loading
find %{buildroot}%{python3_sitelib} -name "pdu.py" -exec sed -i "/#!/d" {} \;
find %{buildroot}%{python3_sitelib} -name "doip.py" -exec sed -i "/#!/d" {} \;
%fdupes %{buildroot}%{python3_sitelib}

%check
cd test && ./run_tests -c configs/linux.utsc -K ci_only -K scanner -K netaccess

%files
%license LICENSE
%doc README.md
%{_bindir}/scapy
%{_mandir}/man1/scapy.1%{?ext_man}
%{python3_sitelib}/scapy*

%changelog
* Tue Nov  5 2024 Robert Frohl <rfrohl@suse.com>
- Update to 2.6.1
  * On linux machines with IPv6 disabled, Scapy would crash on startup
  * The scapy.1 manpage was no longer installed
  * Upon the first startup, there could be a crash related to the creation of
    Scapy's XDG-* related folders.
  * other small bugs that could lead to issues during packaging.
    Thanks to the downstream package maintainers for their help.
* Mon Oct  7 2024 Robert Frohl <rfrohl@suse.com>
- Fix load of embedded manufdb, by explicitly targeting non-executable-scripts
- Fix /etc paths to point to /usr/etc in published rpm.
- Enable unit tests to find issues earlier.
* Wed Oct  2 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Move sed call to fix reproducible builds (boo#1231253)
* Mon Sep 30 2024 Robert Frohl <rfrohl@suse.com>
- Update to 2.6.0
  * support for RFC6874-like scope identifiers. This is very useful for
    multicast IPs as one can now do the following on L3:
    sr(IP(dst="224.0.0.1%%eth0")/..., multi=True)
  * using the iface= argument is deprecated on level3 functions (send, sr, sr1),
    as its behavior was undefined. It remains in use for level2
    functions (sendp, srp, srp1). RFC6874-like scope identifiers should be used.
  * the internals that read the routes and interfaces configuration have been
    rewritten on Linux and BSD:
  - on linux, to use RTNETLINK. (this should help on machines that have huge BPG tables)
  - on *BSDs, to use PF_ROUTE.
  - on Linux, NetBSD and FreeBSD, link-local and multicast routes should now properly be loaded
  * new Windows protocols:
  - DCE/RPC: DCERPC_Client and DCERPC_Server with support for NCACN_IP_TCP and NCACN_NP
  - SMB2/3:
  * Protocol refactor, many more SMB2/3 structures supported
  * Server (class + 'simple' util smbserver()) (2.0.2 to 3.1.1)
  * Client (class + interactive CLI smbclient()) (2.0.2 to 3.1.1)
  * SMB socket, RPC over SMB socket, etc.
  - Kerberos:
  * KerberosSSP to use in SMB/RPC clients/servers, [MS-KILE] variants, SFU and more
  * Crypto: use cryptography, latest RFC8009, GSS_WrapEx support, typing, etc.
  * Util functions krb_as_req, krb_tgt_req, kpasswd (both modes), etc.
  * Ticketer++: ccache support, ask/renew/resign/edit tickets, etc
  - NTLM:
  * refactor, clean SSP
  - Extensive GSSAPI / SPNEGO support
  - LDAP
  * Fixes, ASN.1 Windows variation support
  * dclocator, answering machine for "LDAP PING", etc.
  * add a (very) basic LDAP_client (support for various binding mechanisms, encryption, etc.)
- More features, bug fixes and updated protocol support as listed in:
  https://github.com/secdev/scapy/releases/tag/v2.6.0
* Thu Dec 14 2023 Martin Hauke <mardnh@gmx.de>
- Add python3-cryptography to BuildRequires to have out of the
  box support for
  + PKI & TLS crypto-related features
  + WEP decryption/encryption. (Dot11)
  + IPsec encryption/authentication.
- Recommend python3-PyX to be able to be able to use psdump() or
  pdfdump().
- Recommend python3-ipython for better experience when working in
  interactive mode (command completion, history, ...).
  mode
- Add workaround for openSUSE where /etc/protocols and
  /etc/protocols no longer live in /etc/ but /usr/etc/
- Run spec-cleaner
* Mon Dec 11 2023 Martin Hauke <mardnh@gmx.de>
- Update URL
- Drop obsolete suse version check for 1110
- Use python rpm macros during %%build and %%install
- Do not install test scripts - %%{python3_sitelib}/test/
* Sun Dec 25 2022 Robert Frohl <rfrohl@suse.com>
- Update to 2.5.0
  * Main Changes
  - Type hinting of Scapy core: Scapy now provides type hintings for all of its core
  - Python 3.9 and 3.10 support
  - enhanced loopback interface support on Linux, *BSD, and Windows
  - SPDX License identifiers added
  - several major CLI improvements, especially in autocompletion
  * Core
  - improved support of BPF
  - support pcapng writing, comments, TLS secrets decryption block
  - Re-work how sent_time is shared across packets iterators
  - support new LINUX_SLL2 packet type (new tcpdump versions)
  - pipes: performances issues fixed
  - tools: fixes to hexdiff, lhex...
  * Layers
  - new layers related to Windows: DCERPC/NTLM/KERBEROS/GSSAPI/SPNEGO/(C)LDAP.
  - new contrib layers: ESMC/RTPS/RTPC/metawatch
  - rework Netbios/SMB1/SMB2, basic SMB clients & server, ntlm relay
  - several fixes to the TLS implementation
  - major zigbee/6lowpan improvements
  - bug fixes in TLS: properly support FFDH, fix the TLS 1.3 notebooks... among other things
  - p0f module update
  - IPsec: fixes, x25519 support...
  - various updates to the ASN.1 engine
  - IKEv2: fixes, UDP encapsulation
  - STUN support
  - Postgres line protocol 3.0 support
  - EDNS0 client subnet support
  - ESMC protocol added
  - support TCP-MD5 and TCP-AO options
  - ERF Ethernet Support
  - many fixes: modbus, 802.11, BTLE, SCTP, DNS, LLDP, Kerberos, RTPS, DHCP, MQTT, BGP, L2TP...
  * Automotive
  - ISOTPSoftSocket: Bug fixes and performance improvements
  - IPv6 support for DoIP
  - Bugfixes for DoIP
  - UDS-, GMLAN- and OBD-Scanner refactoring
  - CANFD support
  * Misc
  - new sanity rules prevent fields from having the same name in all packets
  - archives of the Scapy repo should now have more consistent hashes
* Tue Apr 20 2021 Robert Frohl <rfrohl@suse.com>
- Update to 2.4.5
  * Core
  - Python 3.9 support
  - New interfaces system. `conf.iface` is now an object (retro-compatible as a
    string) which contains additional information about the interface and
    allows for an automatic selection of the socket type. `conf.ifaces` now lists
    all available interfaces.
  - Fix BSD support. Improve filters handling on Linux and `libpcap`
  - Automaton: support for `STOP` event - allows to cleanly end an Automata.
    Implemented in all Scapy's automatons
  - [Deprecated] Naming different fields with the same name will now raise a
    deprecation warning. This behavior has never properly worked and should never
    be necessary
  - Enhance `Net` and `Net6`
  - Improvements to scapy's logging, colored output and to UTscapy
  - Fix edge-cases with `ConditionalField` and `MultipleTypeField` to make them
    more resilient
  - [Doc] Enhancements: improved `MultipleTypeField` handling, add `view source`.
  * Layers
  - 6LoWPAN refactor
  - TLS improvements (TLS 1.3 server downgrade, TLS 1.2 EXT MS...)
  - HTTP improvements (http_request, support for zstd...)
  - Refactor TunTap support
  - Cleanup MACsec
  - Many small bug fixes or improvements to layers (SMB2, BFD, DNS, Zigbee,
    EAP, HomeplugGP, DHCPv6, 802.11...)
  * Automotive
  - Renaming of ENET to HSFZ
  - Added XCP layer
  - Added DoIP layer
  - Renaming of ECU to Ecu
  - Refactoring of EcuState class to be more versatile
  - Minor updates to the documentation
* Thu Sep  3 2020 Robert Frohl <rfrohl@suse.com>
- Update to 2.4.4
  * Core
  - fix how timestamps are measured on layer 3 (broken since 2.4.1)
  - drop DNET support (deprecated since 2.4.0)
  - Scapy will now use libpcap instead of tcpdump to compile the filters (tcpdump is still used to filter pcaps)
  - major changes to the online doc and more doc to many functions
  * Layers
  - New layers (homeplug sg, smb2, NSH, RPL, ERSPAN, BFD, ROCE...)
  - TLS: TLS 1.3 support & many fixes
  - 802.11 improvements / WPA3 detection
  - Netflow 9 fixes
  - Major refactor & changes of the Automotive layers
  - HTTP changes
  - DHCPv6 fixes according to revision of the RFC
  - Bluetooth improvements (+BLE)
  - minor fixes to Radius, PPP, GTP, IPsec, CDP, VTP, HTTP/2, ...
* Thu Aug  8 2019 Robert Frohl <rfrohl@suse.com>
- Update to 2.4.3
  * Core
  - latency improvements
  - sniff() can be used to test BPF fiters on pcap files
  - more unit tests and Python3 compatibility
  - asynchronous sniffing
  - UTScapy vim syntax highlighting
  - Console / IPython integration improvements
  * Layers
  - New:
    HTTP (from the deprecated scapy-http module), TLS 1.3, ATA over Ethernet, OVD, IEC 60870-5-104, enip, ...
  - Improved:
    NetflowV9, ISOTP, Zigbee, RTR, BLE, PPI, DNS, LLDP, Bluetooth/BTLE rework, PPI / 802.11 improvements
* Tue Jan 15 2019 Robert Frohl <rfrohl@suse.com>
- update to 2.4.2
  * Core
  - Python 3.7 support
  - unit testing is now 100%% tox based
  * Layers
  - Many automotive related layers added (ISO-TP...)
  - New:
    EtherCat, OPCDA, SOCKS, USBpcap, RPKI
  - Improved:
    MACsec, MQTT, MPLS, DNS, ARP, Dot15d4, Zigbee, Bluetooth4LE, RadioTap
* Fri Nov  9 2018 Robert Frohl <rfrohl@suse.com>
- update to 2.4.0
  * Core
  - Pcap/PcapNg improvements
  - OSX 802.11 monitor mode
  - Krack AP module
  - iPython support
  * Layers
  - major changes
  * TLS (including TLS1.3), X.509
  - New
  * HTTP/2, EAP-TTLS, TACACS, MQTT
  - Improved
  * IPv6, SCTP, NTP, PPTP, CDP, BGP, ISIS
- use python3 by default
* Fri Aug 16 2013 hpj@urpla.net
- add note about testing requirements, local test run successful
* Fri Aug 16 2013 speilicke@suse.com
- Spec cleanup: license header, simplified macro usage, explicit file
  list, dropped %%clean section
- Provide/obsolete python-scapy, it's the same software
- Use tarball from PyPI and a source URL so that it can be verified
- Remove documentation from tarball and thus from src and binary RPMs,
  we are not allowed to distribute it
* Tue Feb 12 2013 hpj@urpla.net
- update to 2.2.0
* Thu Jul 15 2010 pascal.bleser@opensuse.org
- initial package (2.1.1)
